.. adfluo documentation master file, created by
   sphinx-quickstart on Sat Jan 16 00:42:36 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to adfluo's documentation!
==================================

Installation
------------

You can install `adfluo` from Pypi using

.. code-block:: bash

   pip install adfluo

Documentation Index
===================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   user_guide
   how_tos
   cli
   reference
   changelog

